# -*- coding: utf-8 -*-
from setuphelpers import *
import json


def update_package():
    # Declaring local variables
    package_updated = False
    proxies = get_proxies()
    if not proxies:
        proxies = get_proxies_from_wapt_console()
    app_name = control.name
    api_url = "https://sourceforge.net/projects/turbovnc/best_release.json"
    bin_contains = "TurboVNC-"
    bin_name_dict = {
        "windows-x64": bin_contains + "%s-x64.exe",
        "windows-x86": bin_contains + "%s-x86.exe",
        "macos-x64": bin_contains + "%s-x86_64.dmg",
        "linux-x64": "turbovnc-%s.tar.gz",
    }
    sub_bin_name = bin_name_dict[control.target_os + "-" + ensure_list(control.architecture)[0]]

    # Getting latest version information from official sources
    print("API used is: %s" % api_url)
    json_load = json.loads(wgets(api_url, proxies=proxies))
    for download in json_load["platform_releases"]:
        if bin_contains in json_load["platform_releases"][download]["filename"]:
            version = json_load["platform_releases"][download]["filename"].split("/")[1]
            break
    latest_bin = sub_bin_name % version.split(" ")[0]
    download_url = "https://sourceforge.net/projects/turbovnc/files/%s/%s/download" % (version, latest_bin)
    version = version.split(" ")[0]

    # Downloading latest binaries
    print("Latest %s version is: %s" % (app_name, version))
    print("Download URL is: %s" % download_url)
    if not isfile(latest_bin):
        print("Downloading: %s" % latest_bin)
        wget(download_url, latest_bin, proxies=proxies)
    else:
        print("Binary is present: %s" % latest_bin)

    # Deleting outdated binaries
    remove_outdated_binaries(latest_bin)

    # Checking version from file
    if get_os_name() == "Windows" and "windows" in control.target_os.lower():
        version_from_file = get_version_from_binary(latest_bin)
        if Version(version_from_file, 4) != Version(version, 4) and version_from_file != "":
            error("ERROR: Binary file version do NOT corresponds to online version")
        else:
            print("INFO: Binary file version corresponds to online version")

    # Changing version of the package
    if Version(version, 4) > Version(control.get_software_version(), 4):
        print("Software version updated (from: %s to: %s)" % (control.get_software_version(), Version(version)))
        package_updated = True
    else:
        print("Software version up-to-date (%s)" % Version(version))
    control.set_software_version(version)
    control.save_control_to_wapt()

    # Validating update-package-sources
    return package_updated
